<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Dodaj pluginy</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Szukaj:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Dodaj widżet</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(tylko jedna instancja może być uruchomiona)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation type="vanished">Konfiguruj panel</translation>
    </message>
    <message>
        <source>Panel size</source>
        <translation type="vanished">Rozmiar panelu</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="vanished">Rozmiar:</translation>
    </message>
    <message>
        <source>px</source>
        <translation type="vanished">px</translation>
    </message>
    <message>
        <source>Use automatic sizing</source>
        <translation type="vanished">Użyj automatycznego dopasowywania</translation>
    </message>
    <message>
        <source>Panel length &amp;&amp; position</source>
        <translation type="vanished">Długość i położenie panelu</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Lewa</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Środek</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Prawa</translation>
    </message>
    <message>
        <source>%</source>
        <translation type="vanished">%</translation>
    </message>
    <message>
        <source>Alignment:</source>
        <translation type="vanished">Wyrównanie:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="vanished">Długość:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="vanished">Pozycja:</translation>
    </message>
    <message>
        <source>Top of desktop</source>
        <translation type="vanished">Górna krawędź pulpitu</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation type="vanished">Lewa krawędź pulpitu</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation type="vanished">Prawa krawędź pulpitu</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation type="vanished">Dolna krawędź pulpitu</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation type="vanished">Górna krawędź pulpitu %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation type="vanished">Lewa krawędź pulpitu %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation type="vanished">Prawa krawędź pulpitu %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation type="vanished">Dolna krawędź pulpitu %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Konfiguruj Panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Widżety</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Konfiguruj panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Rozmiar ikon:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Długość:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Ujemna ilość pikseli powoduje zmniejszenie panelu .&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Np. &quot;Długość&quot; ustawiona na -100px, rozmiar ekranu 1000px, długość panelu wyniesie 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Ilość wierszy:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Wyrównanie i pozycja</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Zero oznacza brak animacji</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Czas trwania animacji:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>Lewa</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>Środek</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>Prawa</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>A&amp;utomatyczne ukrywanie</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Zero oznacza brak oczekiwanai</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Pokaż z opóźnieniem:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Nie pozwalaj na wyświetlanie zmaksymalizowanych okien pod oknem panelu</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation>Rezerwuj przestrzeń na ekranie</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Własny styl</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Kolor czcionki:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Kolor tła:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Przeźroczystość tła:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Compositing jest wymagany aby uzyskać przeźroczystość.&lt;/small</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Obrazek tła:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Wyrównanie:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Pozycja:</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">Autoukrywanie</translation>
    </message>
    <message>
        <source>Styling</source>
        <translation type="vanished">Wygląd</translation>
    </message>
    <message>
        <source>Custom font color:</source>
        <translation type="vanished">Własny kolor czcionki:</translation>
    </message>
    <message>
        <source>Custom background image:</source>
        <translation type="vanished">Własny obrazek tła:</translation>
    </message>
    <message>
        <source>Custom background color:</source>
        <translation type="vanished">Własny kolor tła:</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="vanished">Przezroczystość</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>Górna krawędź pulpitu</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>Lewa krawędź pulpitu</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>Prawa krawędź pulpitu</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>Dolna krawędź pulpitu</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>Górna krawędź pulpitu %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>Lewa krawędź pulpitu %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>Prawa krawędź pulpitu %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>Dolna krawędź pulpitu %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>Wybierz kolor</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Obrazki (*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>Wybierz obrazek</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Konfiguruj Pluginy</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Notka: zmiany tu dokonane nie mogą zostać zresetowane.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Do góry</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>W dół</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <source>Add Panel Widgets</source>
        <translation type="vanished">DOdaj Widgety</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1066"/>
        <location filename="../../../lxqtpanel.cpp" line="1091"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Configure Panel</source>
        <translation>Konfiguruj Panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1099"/>
        <source>Manage Widgets</source>
        <translation>Zarządzaj widżetami</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1105"/>
        <source>Add New Panel</source>
        <translation>Dodaj nowy panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1112"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Usuń panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1117"/>
        <source>Lock This Panel</source>
        <translation>Zablokuj ten panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1259"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Usuń panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1260"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Usunięcie panelu nie może zostać cofnięte.
Czy chcesz usunąć ten panel?</translation>
    </message>
    <message>
        <source>Configure Panel...</source>
        <translation type="vanished">Konfiguruj Panel...</translation>
    </message>
    <message>
        <source>Add Panel Widgets...</source>
        <translation type="vanished">Dodaj Widgety...</translation>
    </message>
    <message>
        <source>Add Panel</source>
        <translation type="vanished">Dodaj Panel</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translation type="vanished">Usuń panel</translation>
    </message>
    <message>
        <source>Configure panel...</source>
        <translation type="vanished">Konfiguruj panel...</translation>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation type="vanished">Dodaj wtyczkę ...</translation>
    </message>
</context>
<context>
    <name>LXQtPanelPlugin</name>
    <message>
        <source>Configure</source>
        <translation type="vanished">Konfiguruj</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="vanished">Przesuń</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Usuń</translation>
    </message>
</context>
<context>
    <name>LXQtPanelPrivate</name>
    <message>
        <source>Configure panel</source>
        <translation type="vanished">Konfiguruj panel</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Konfiguruj &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Przesuń &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Usuń &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Użyj innego pliku konfiguracyjnego.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Plik konfiguracyjny</translation>
    </message>
</context>
</TS>
